package com.clx.apk_update

import android.content.Context
import android.content.Intent
import android.util.Log
import androidx.annotation.NonNull

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import java.io.File

/** ApkUpdatePlugin */
class ApkUpdatePlugin : FlutterPlugin, MethodCallHandler {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private lateinit var channel: MethodChannel
    private val tag = "ApkUpdatePlugin"
    private lateinit var mContext: Context

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        mContext = flutterPluginBinding.applicationContext
        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "apk_update")
        channel.setMethodCallHandler(this)
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        Log.d(tag, "onMethodCall: method = ${call.method} arguments = ${call.arguments}")
        if (call.method == "installApk") {
            val path = call.argument<String?>("path")
            if (path == null || path == "") {
                Log.d(tag, "onMethodCall: path is null")
                result.error("error", "path is null", null)
                return
            }
            openFile(path)
        } else {
            result.notImplemented()
        }
    }

    /**
     * 安装 文件（APK）
     */
    private fun openFile(path: String) {
        val intents = Intent()
        intents.action = Intent.ACTION_VIEW
        intents.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
        FileProvider7.setIntentDataAndType(
            mContext, intents, "application/vnd.android.package-archive", File(path), false
        )
        mContext.startActivity(intents)
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }
}
